@@ -3,7 +3,7 @@ use crate::state::StateManager;
 use crate::Value;
 
 #[repr(C)]
-#[cfg_attr(feature = "std", derive(serde::Serialize, serde::Deserialize))]
+#[derive(Debug)]
 pub struct FlipFlopFilter {
     state: bool,
 }
@@ -14,7 +14,6 @@ impl FlipFlopFilter {
     }
 }
 
-#[cfg_attr(feature = "std", typetag::serde(name = "flip_flop_filter"))]
 impl Filter for FlipFlopFilter {
     fn filter(&mut self, value: &Value, _state_manager: &mut StateManager) -> bool {
         match value {
